@@ -8,19 +8,28 @@ import math
 import re
 import time
 import re
+from queue import Queue
 from typing import List
 
-def to_flat(x: dict, prefix: str = '') -> dict:
+def to_flat(x: dict) -> dict:
+    q: Queue = Queue()
+    q.put(('', x))
     result: dict = {}
-    for k, v in x.items():
-        new_prefix = f"{prefix}_{k}" if prefix else k
-        if isinstance(v, dict):
-            result.update(to_flat(v, new_prefix))
-        elif isinstance(v, list):
-            for i, elem in enumerate(v):
-                result[f"{new_prefix}[{i}]"] = elem
+    prefix: str
+    o: dict
+    while not q.empty():
+        prefix, o = q.get()
+        if isinstance(o, dict):
+            for k, v in o.items():
+                if prefix == "":
+                    q.put((f"{k}", v))
+                else:
+                    q.put((f"{prefix}_{k}", v))
+        elif isinstance(o, list):
+            for i, v in enumerate(o):
+                q.put((f"{prefix}[{i}]", v))
         else:
-            result[new_prefix] = v
+            result[prefix] = o
     return result
 
 def is_number(s: str) -> bool:
@@ -48,6 +57,7 @@ def titleToNumber(columnTitle: str) -> int:
 def convertToTitle(columnNumber: int) -> str:
     OFFSET = ord('A') - 1  # A对应的数字
     title = ""
+    columnNumber += 1
     while columnNumber > 0:
         columnNumber -= 1
         num = columnNumber % 26
